package de.intevation.gnv.state;

/**
 * The default implementation of <code>InputValue</code>. InputValue objects are
 * used to store meta information about <code>InputData</code> objects.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public class DefaultInputValue implements InputValue {

    /**
     * The UID of this Class.
     */
    private static final long serialVersionUID = -8518824299166180986L;
    private String name = null;
    private String type = null;
    private boolean multiselect = false;
    private int usedInQueries = 1;
    private String defaultValue = "N/N";

    /**
     *
     * @param name
     * @param type
     * @param defaultValue
     * @param multiselect
     */
    public DefaultInputValue(String name, String type, String defaultValue,
                             boolean multiselect) {
        this(name, type, multiselect, 1);
        this.defaultValue = defaultValue;

    }

    /**
     * Constructor
     * @param name
     * @param type
     * @param multiselect
     * @param usedInQueries
     */
    public DefaultInputValue(String name, String type, boolean multiselect,
                             int usedInQueries) {
        this.name = name;
        this.type = type;
        this.multiselect = multiselect;
        this.usedInQueries = usedInQueries;
    }

    /**
     * @return
     */
    public String getName() {
        return this.name;
    }

    /**
     * @return
     */
    public String getType() {
        return this.type;
    }

    /**
     * Returns the information as string.
     *
     * @return information as string.
     */
    @Override
    public String toString() {
        return "InputValue " + this.name + " ==> " + this.type
               + "==> multiselect: " + this.multiselect;
    }

    /**
     * @return
     */
    public boolean isMultiselect() {
        return this.multiselect;
    }

    /**
     *
     * @return
     */
    public int usedInQueries() {
        return this.usedInQueries;
    }

    /**
     *
     * @return
     */
    public String getDefaultValue() {
        return this.defaultValue;
    }

}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :