package de.intevation.gnv.state.describedata;

import java.util.ArrayList;
import java.util.Collection;

/**
 * This is the default implementation of <code>NamedCollection</code>.
 *
 * @param <E> The type which the objects stored in this object are from.
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public class NamedArrayList<E> extends ArrayList<E> implements
                                                   NamedCollection<E> {
    /**
     *
     */
    private static final long serialVersionUID = 8172229594749676354L;

    private String name = null;

    private boolean multiSelect = false;

    /**
     * Constructor
     *
     * @param name The name of this collection.
     */
    public NamedArrayList(String name) {
        this.name = name;
    }

    /**
     * Constructor
     *
     * @param name The name of this collection.
     * @param initialCapacity The initial capacity of this collection.
     */
    public NamedArrayList(String name, int initialCapacity) {
        super(initialCapacity);
        this.name = name;
    }

    /**
     * Constructor
     *
     * @param name The name of this collection.
     * @param c the collection whose elements are to be placed into this list.
     */
    public NamedArrayList(String name, Collection<E> c) {
        super(c);
        this.name = name;
    }

    public String getName() {
        return this.name;
    }

    public boolean isMultiSelect() {
        return multiSelect;
    }

    public void setMultiSelect(boolean multiSelect) {
        this.multiSelect = multiSelect;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :